# Review Criteria for Custom Reports
### On this page
  * [Report Metadata Review](https://help.sap.com/docs/leanix/ea/review-criteria-custom-reports#report-metadata-review)
  * [Technical Review](https://help.sap.com/docs/leanix/ea/review-criteria-custom-reports#technical-review)
  * [Functional Review](https://help.sap.com/docs/leanix/ea/review-criteria-custom-reports#functional-review)


Before you publish your custom report on the SAP LeanIX Store, we review it. Learn about the key steps in this process and the review criteria.
This topic outlines the criteria that we're using during the custom report review process. The following steps illustrate our approach to reviewing a report before its publication.
As a general rule, the entire review process should not take longer than 10 business days. However, the duration may occasionally extend due to the complexity and volume of ongoing review requests. If the review involves minor changes to an existing report, please inform us to facilitate a faster process.
